.. _pecan_hooks:

:mod:`pecan.hooks` -- Pecan Hooks
=================================

The :mod:`pecan.hooks` module includes support for creating Pecan
``hooks`` which are a simple way to hook into the request processing
of requests coming into your application to perform cross-cutting tasks.

.. automodule:: pecan.hooks
  :members:
  :show-inheritance: